op-alloy-rpc-types-engine
Optimism RPC types for the engine namespace.
Re-exports
pub use payload::OpExecutionPayload;pub use payload::error::OpPayloadError;pub use payload::v3::OpExecutionPayloadEnvelopeV3;pub use payload::v4::OpExecutionPayloadEnvelopeV4;pub use payload::v4::OpExecutionPayloadV4;pub use flashblock::OpFlashblockError;pub use flashblock::OpFlashblockPayload;pub use flashblock::OpFlashblockPayloadBase;pub use flashblock::OpFlashblockPayloadDelta;pub use flashblock::OpFlashblockPayloadMetadata;
Modules
- flashblock
- Flashblock Support for Optimism
- payload
- Versioned Optimism execution payloads
Structs
- OpExecution
Data - Struct aggregating
OpExecutionPayloadandOpExecutionPayloadSidecarand encapsulating complete payload supplied for execution. - OpExecution
Payload Envelope - A thin wrapper around
OpExecutionPayloadthat includes the parent beacon block root. - OpExecution
Payload Sidecar - Container type for all available additional
newPayloadrequest parameters that are not present in theExecutionPayloadobject itself. - OpNetwork
Payload Envelope - Optimism execution payload envelope in network format.
- OpPayload
Attributes - Optimism Payload Attributes
- Payload
Hash - Represents the Keccak256 hash of the block
- Protocol
Version Format V0 - The Protocol Version V0 format. Encoded as 31 bytes with the following structure:
- Superchain
Signal - Superchain Signal information.
Enums
- Forkchoice
Update Version - The version of the engine api.
- Payload
Envelope Encode Error - Errors that can occur when encoding a payload envelope.
- Payload
Envelope Error - Errors that can occur when decoding a payload envelope.
- Protocol
Version - Formatted Superchain Protocol Version.
- Protocol
Version Error - An error that can occur when encoding or decoding a
ProtocolVersion.